<?php

namespace Drupal\related_nodes_block;

/**
 * Provides constants and short helper methods for the module.
 */
class Module {
  /**
   * Machine name of the module.
   *
   * @var string NAME
   */
  const NAME = 'related_nodes_block';

  /**
   * Human-readable label of the module.
   *
   * @var string LABEL
   */
  const LABEL = 'Related Nodes Block';

  /**
   * Module webpage.
   *
   * @var string MODULE_WEBPAGE
   */
  const MODULE_WEBPAGE = 'https://www.drupal.org/project/' . self::NAME;

  /**
   * Only when true, debug function writes messages.
   *
   * @var boolean DEBUG_MODE
   */
  const DEBUG_MODE = FALSE;

  /**
   * Writes variable values to a static debug file.
   *
   * @param mixed $var
   *   Variable to print.
   * @param string $php_func
   *   Base PHP function to use.
   */
  public static function debug($var, $php_func = '') {
    static $log_dir = __DIR__ . '/logs';

    if (!self::DEBUG_MODE) {
      return;
    }

    switch ($php_func) {
      case 'pr':
        $var = print_r($var, TRUE) . PHP_EOL;
        break;

      case 'vd':
        ob_start();
        var_dump($var);
        $var = ob_get_clean();
        ob_end_clean();
        break;

      default:
        if (!is_string($var)) {
          $var = 'DEBUG: Cannot print non-string input.';
        }
        $var .= PHP_EOL;
        break;
    }

    if (!is_dir($log_dir)) {
      mkdir($log_dir, 0777, TRUE);
    }
    file_put_contents($log_dir . '/debug.log', '[' . date('Y-m-d h:i:s') . '] ' . $var, FILE_APPEND);
  }

}
